@@ -17,14 +17,15 @@ type ChartDimension = dict[Literal["width"] | Literal["height"], float]
 type ChartDimensions = dict[str, ChartDimension]
 
 
-def widget_type_to_instance(
+def create_widget_instance(
     widget_type: Type[Widget],
     input_value: str | None,
     chart_dimension: ChartDimension | None,
 ):
     if issubclass(widget_type, Select):
         assert input_value is not None
-        widget = widget_type(selected=input_value)
+        widget = widget_type()
+        widget.set_selected(input_value)
     elif issubclass(widget_type, Chart):
         assert chart_dimension is not None
         widget = widget_type(
@@ -53,7 +54,7 @@ def get_callback_in_and_outputs(
 
         widget_type, widget_id, widget_io = process_callback_arg(callback_fn, param)
 
-        widget = widget_type_to_instance(
+        widget = create_widget_instance(
             widget_type=widget_type,
             input_value=additional_inputs.get(widget_id, None),
             chart_dimension=chart_dimensions_dict.get(widget_id, None),
@@ -73,7 +74,7 @@ def render_callback_outputs(
     result: str = ""
 
     for callback_output in callback_outputs.values():
-        if callback_output._cancel_update:
+        if callback_output._cancel_update or not callback_output._updated:
             continue
         if isinstance(callback_output, Chart):
             result += "\n" + callback_output.render_chart(request)
