@@ -20,12 +20,12 @@ def auth_request(request: HttpRequest) -> HttpResponse:
 
     if user is not None:
         login(request, user)
-        return redirect("home")
+        return redirect("/")
     else:
         messages.error(request, "Login insuccessful, please try again.")
-        return redirect("login-page")
+        return redirect("/accounts/login")
 
 
 def logout_view(request: HttpRequest) -> HttpResponse:
     logout(request)
-    return redirect("home")
+    return redirect("/")
