@@ -1,5 +1,4 @@
 from django.http import HttpRequest
-from django.contrib.humanize.templatetags.humanize import intcomma
 from .base import Chart
 from pydantic import BaseModel
 from .utils import Point, Space
@@ -56,6 +55,7 @@ class HistChart(Chart):
         df = pl.from_dict({"value": values})
         series = df.get_column("value")
         self.set_points_from_series(series, bin_count)
+        self._updated = True
 
     def set_points_from_series(self, series: pl.Series, bin_count: int) -> None:
         hist = series.hist(bin_count=bin_count)
@@ -105,7 +105,7 @@ class HistChart(Chart):
 
         if multiplier != 1:
             multiplier_text = Text(
-                text=f"x {intcomma(multiplier)}",
+                text=f"x {multiplier:,}",
                 pos=Point(x=y_label_width * 2, y=title_height),
                 y_align="bottom",
                 font_size=x_axis_font_size,
