@@ -2,7 +2,7 @@ from django.http import HttpRequest
 
 from pydantic import BaseModel
 
-from ..base import ControlWidget
+from newsflash.base import ControlWidget
 from newsflash.callback.builder import construct_callback
 from newsflash.callback.models import Callback
 
