@@ -1,6 +1,3 @@
-from newsflash_cli.main import setup_django
-setup_django()
-
 from typing import Any, Annotated
 import unittest
 
@@ -29,8 +26,9 @@ class TestCallback(unittest.TestCase):
             endpoint_name="ABC",
             trigger_event="click",
             inputs=["button-id-input"],
-            targets=["bar-chart-id"],
-            target_wrapper_ids="#bar-chart-id-wrapper",
+            targets=["bar-chart-id", "button-id"],
+            # TODO: button has no wrapper so this ID does not exist
+            target_wrapper_ids="#bar-chart-id-wrapper, #button-id-wrapper",
         )
 
         self.assertEqual(result, expected)
